==> okteta_0.25.5.orig.tar.xz: okteta-0.25.5/core/piecetable/tests/insertpiecetablechangeabstractpiecetablechangeiftest.cpp <==
/*
    This file is part of the Okteta Core library, made within the KDE community.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "insertpiecetablechangeabstractpiecetablechangeiftest.h"

// test object
#include <piecetable/insertpiecetablechange.h>
// lib
#include <piecetable/piecetable.h>
// Qt
#include <QTest>

namespace KPieceTable {

static const Address InsertOffset = 30;
static const Size InsertLength = 80;
static const Address StorageOffset = 67;

AbstractPieceTableChange* InsertPieceTableChangeAbstractPieceTableChangeIfTest::createPieceTableChange()
{
    InsertPieceTableChange* pieceTableChange =
        new InsertPieceTableChange(InsertOffset, InsertLength, StorageOffset);

    return pieceTableChange;
}

void InsertPieceTableChangeAbstractPieceTableChangeIfTest::changePieceTable(PieceTable* pieceTable)
{
    pieceTable->insert(InsertOffset, InsertLength, StorageOffset);
}

void InsertPieceTableChangeAbstractPieceTableChangeIfTest::deletePieceTableChange(AbstractPieceTableChange* pieceTableChange)
{
    delete pieceTableChange;
}

}

QTEST_GUILESS_MAIN(KPieceTable::InsertPieceTableChangeAbstractPieceTableChangeIfTest)

==> okteta-0.26.0.tar.xz: okteta-0.26.0/core/piecetable/tests/insertpiecetablechangeabstractpiecetablechangeiftest.cpp <==
/*
    This file is part of the Okteta Core library, made within the KDE community.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "insertpiecetablechangeabstractpiecetablechangeiftest.hpp"

// test object
#include <piecetable/insertpiecetablechange.hpp>
// lib
#include <piecetable/piecetable.hpp>
// Qt
#include <QTest>

namespace KPieceTable {

static constexpr Address InsertOffset = 30;
static constexpr Size InsertLength = 80;
static constexpr Address StorageOffset = 67;

AbstractPieceTableChange* InsertPieceTableChangeAbstractPieceTableChangeIfTest::createPieceTableChange()
{
    auto* pieceTableChange = new InsertPieceTableChange(InsertOffset, InsertLength, StorageOffset);

    return pieceTableChange;
}

void InsertPieceTableChangeAbstractPieceTableChangeIfTest::changePieceTable(PieceTable* pieceTable)
{
    pieceTable->insert(InsertOffset, InsertLength, StorageOffset);
}

void InsertPieceTableChangeAbstractPieceTableChangeIfTest::deletePieceTableChange(AbstractPieceTableChange* pieceTableChange)
{
    delete pieceTableChange;
}

}

QTEST_GUILESS_MAIN(KPieceTable::InsertPieceTableChangeAbstractPieceTableChangeIfTest)
